==> spip_3.2.11.orig.tar.xz: ecrire/charsets/cp1250.php <==
<?php

/**
 * Déclaration des correspondances entre charsets cp1250 (europe centrale et de l'est) et unicode
 *
 * @author Mathieu Lutfy
 * @link http://www.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP1250.TXT
 *
 * @package SPIP\Core\Charsets
 **/

$GLOBALS['CHARSET']['cp1250'] = array(
	0x80 => 0x20AC,
	0x82 => 0x201A,
	0x84 => 0x201E,
	0x85 => 0x2026,
	0x86 => 0x2020,
	0x87 => 0x2021,
	0x89 => 0x2030,
	0x8A => 0x0160,
	0x8B => 0x2039,
	0x8C => 0x015A,
	0x8D => 0x0164,
	0x8E => 0x017D,
	0x8F => 0x0179,
	0x91 => 0x2018,
	0x92 => 0x2019,
	0x93 => 0x201C,
	0x94 => 0x201D,
	0x95 => 0x2022,
	0x96 => 0x2013,
	0x97 => 0x2014,
	0x99 => 0x2122,
	0x9A => 0x0161,
	0x9B => 0x203A,
	0x9C => 0x015B,
	0x9D => 0x0165,
	0x9E => 0x017E,
	0x9F => 0x017A,
	0xA0 => 0x00A0,
	0xA1 => 0x02C7,
	0xA2 => 0x02D8,
	0xA3 => 0x0141,
	0xA4 => 0x00A4,
	0xA5 => 0x0104,
	0xA6 => 0x00A6,
	0xA7 => 0x00A7,
	0xA8 => 0x00A8,
	0xA9 => 0x00A9,
	0xAA => 0x015E,
	0xAB => 0x00AB,
	0xAC => 0x00AC,
	0xAD => 0x00AD,
	0xAE => 0x00AE,
	0xAF => 0x017B,
	0xB0 => 0x00B0,
	0xB1 => 0x00B1,
	0xB2 => 0x02DB,
	0xB3 => 0x0142,
	0xB4 => 0x00B4,
	0xB5 => 0x00B5,
	0xB6 => 0x00B6,
	0xB7 => 0x00B7,
	0xB8 => 0x00B8,
	0xB9 => 0x0105,
	0xBA => 0x015F,
	0xBB => 0x00BB,
	0xBC => 0x013D,
	0xBD => 0x02DD,
	0xBE => 0x013E,
	0xBF => 0x017C,
	0xC0 => 0x0154,
	0xC1 => 0x00C1,
	0xC2 => 0x00C2,
	0xC3 => 0x0102,
	0xC4 => 0x00C4,
	0xC5 => 0x0139,
	0xC6 => 0x0106,
	0xC7 => 0x00C7,
	0xC8 => 0x010C,
	0xC9 => 0x00C9,
	0xCA => 0x0118,
	0xCB => 0x00CB,
	0xCC => 0x011A,
	0xCD => 0x00CD,
	0xCE => 0x00CE,
	0xCF => 0x010E,
	0xD0 => 0x0110,
	0xD1 => 0x0143,
	0xD2 => 0x0147,
	0xD3 => 0x00D3,
	0xD4 => 0x00D4,
	0xD5 => 0x0150,
	0xD6 => 0x00D6,
	0xD7 => 0x00D7,
	0xD8 => 0x0158,
	0xD9 => 0x016E,
	0xDA => 0x00DA,
	0xDB => 0x0170,
	0xDC => 0x00DC,
	0xDD => 0x00DD,
	0xDE => 0x0162,
	0xDF => 0x00DF,
	0xE0 => 0x0155,
	0xE1 => 0x00E1,
	0xE2 => 0x00E2,
	0xE3 => 0x0103,
	0xE4 => 0x00E4,
	0xE5 => 0x013A,
	0xE6 => 0x0107,
	0xE7 => 0x00E7,
	0xE8 => 0x010D,
	0xE9 => 0x00E9,
	0xEA => 0x0119,
	0xEB => 0x00EB,
	0xEC => 0x011B,
	0xED => 0x00ED,
	0xEE => 0x00EE,
	0xEF => 0x010F,
	0xF0 => 0x0111,
	0xF1 => 0x0144,
	0xF2 => 0x0148,
	0xF3 => 0x00F3,
	0xF4 => 0x00F4,
	0xF5 => 0x0151,
	0xF6 => 0x00F6,
	0xF7 => 0x00F7,
	0xF8 => 0x0159,
	0xF9 => 0x016F,
	0xFA => 0x00FA,
	0xFB => 0x0171,
	0xFC => 0x00FC,
	0xFD => 0x00FD,
	0xFE => 0x0163,
	0xFF => 0x02D9
);

==> spip_4.4.6+dfsg.orig.tar.xz: ecrire/charsets/cp1250.php <==
<?php

/**
 * Déclaration des correspondances entre charsets cp1250 (europe centrale et de l'est) et unicode
 *
 * @author Mathieu Lutfy
 * @link http://www.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/WINDOWS/CP1250.TXT
 *
 * @package SPIP\Core\Charsets
 **/

$GLOBALS['CHARSET']['cp1250'] = [
	0x80 => 0x20AC,
	0x82 => 0x201A,
	0x84 => 0x201E,
	0x85 => 0x2026,
	0x86 => 0x2020,
	0x87 => 0x2021,
	0x89 => 0x2030,
	0x8A => 0x0160,
	0x8B => 0x2039,
	0x8C => 0x015A,
	0x8D => 0x0164,
	0x8E => 0x017D,
	0x8F => 0x0179,
	0x91 => 0x2018,
	0x92 => 0x2019,
	0x93 => 0x201C,
	0x94 => 0x201D,
	0x95 => 0x2022,
	0x96 => 0x2013,
	0x97 => 0x2014,
	0x99 => 0x2122,
	0x9A => 0x0161,
	0x9B => 0x203A,
	0x9C => 0x015B,
	0x9D => 0x0165,
	0x9E => 0x017E,
	0x9F => 0x017A,
	0xA0 => 0x00A0,
	0xA1 => 0x02C7,
	0xA2 => 0x02D8,
	0xA3 => 0x0141,
	0xA4 => 0x00A4,
	0xA5 => 0x0104,
	0xA6 => 0x00A6,
	0xA7 => 0x00A7,
	0xA8 => 0x00A8,
	0xA9 => 0x00A9,
	0xAA => 0x015E,
	0xAB => 0x00AB,
	0xAC => 0x00AC,
	0xAD => 0x00AD,
	0xAE => 0x00AE,
	0xAF => 0x017B,
	0xB0 => 0x00B0,
	0xB1 => 0x00B1,
	0xB2 => 0x02DB,
	0xB3 => 0x0142,
	0xB4 => 0x00B4,
	0xB5 => 0x00B5,
	0xB6 => 0x00B6,
	0xB7 => 0x00B7,
	0xB8 => 0x00B8,
	0xB9 => 0x0105,
	0xBA => 0x015F,
	0xBB => 0x00BB,
	0xBC => 0x013D,
	0xBD => 0x02DD,
	0xBE => 0x013E,
	0xBF => 0x017C,
	0xC0 => 0x0154,
	0xC1 => 0x00C1,
	0xC2 => 0x00C2,
	0xC3 => 0x0102,
	0xC4 => 0x00C4,
	0xC5 => 0x0139,
	0xC6 => 0x0106,
	0xC7 => 0x00C7,
	0xC8 => 0x010C,
	0xC9 => 0x00C9,
	0xCA => 0x0118,
	0xCB => 0x00CB,
	0xCC => 0x011A,
	0xCD => 0x00CD,
	0xCE => 0x00CE,
	0xCF => 0x010E,
	0xD0 => 0x0110,
	0xD1 => 0x0143,
	0xD2 => 0x0147,
	0xD3 => 0x00D3,
	0xD4 => 0x00D4,
	0xD5 => 0x0150,
	0xD6 => 0x00D6,
	0xD7 => 0x00D7,
	0xD8 => 0x0158,
	0xD9 => 0x016E,
	0xDA => 0x00DA,
	0xDB => 0x0170,
	0xDC => 0x00DC,
	0xDD => 0x00DD,
	0xDE => 0x0162,
	0xDF => 0x00DF,
	0xE0 => 0x0155,
	0xE1 => 0x00E1,
	0xE2 => 0x00E2,
	0xE3 => 0x0103,
	0xE4 => 0x00E4,
	0xE5 => 0x013A,
	0xE6 => 0x0107,
	0xE7 => 0x00E7,
	0xE8 => 0x010D,
	0xE9 => 0x00E9,
	0xEA => 0x0119,
	0xEB => 0x00EB,
	0xEC => 0x011B,
	0xED => 0x00ED,
	0xEE => 0x00EE,
	0xEF => 0x010F,
	0xF0 => 0x0111,
	0xF1 => 0x0144,
	0xF2 => 0x0148,
	0xF3 => 0x00F3,
	0xF4 => 0x00F4,
	0xF5 => 0x0151,
	0xF6 => 0x00F6,
	0xF7 => 0x00F7,
	0xF8 => 0x0159,
	0xF9 => 0x016F,
	0xFA => 0x00FA,
	0xFB => 0x0171,
	0xFC => 0x00FC,
	0xFD => 0x00FD,
	0xFE => 0x0163,
	0xFF => 0x02D9
];
